@@ -59,8 +59,7 @@ class Send(Resource):
         args = self.parser.parse_args()
         message = decoders.from_json(args["message"])
 
-        loop = asyncio.get_event_loop()
-        asyncio.ensure_future(self.app.send(message), loop=loop)
+        asyncio.create_task(self.app.send(message))
 
         return JsonResultResponse(
             True,
@@ -154,8 +153,6 @@ class RESTfulServiceApp(BaseApp):
         )  # debug=False: disable automatic restarting of the Flask server
 
     async def stop(self, *args, **kwargs):
-        await super().stop(*args, **kwargs)
-
         result = requests.post(
             "http://127.0.0.1:5000/shutdown", data={"token": self.secret_key}
         )
@@ -163,4 +160,6 @@ class RESTfulServiceApp(BaseApp):
         if self._flask_process is not None:
             self._flask_process.kill()
 
+        await super().stop(*args, **kwargs)
+
         return result
