@@ -21,6 +21,7 @@ import aioredis
 from wtfix.apps.base import BaseApp
 from wtfix.conf import settings
 from wtfix.core import decoders, utils
+from wtfix.pipeline import BasePipeline
 
 logger = settings.logger
 
@@ -34,7 +35,7 @@ class RedisPubSubApp(BaseApp):
 
     SEND_CHANNEL = "channel:send"
 
-    def __init__(self, pipeline, *args, **kwargs):
+    def __init__(self, pipeline: BasePipeline, *args, **kwargs):
         super().__init__(pipeline, *args, **kwargs)
 
         self.redis_pool = None
@@ -55,15 +56,8 @@ class RedisPubSubApp(BaseApp):
                     )  # Pass message on to pipeline
 
         except asyncio.exceptions.CancelledError:
-            # Cancellation request received - close connections....
             logger.info(f"{self.name}: {asyncio.current_task().get_name()} cancelled!")
 
-            with await self.redis_pool as conn:
-                await conn.unsubscribe(self.SEND_CHANNEL)
-
-            self.redis_pool.close()
-            await self.redis_pool.wait_closed()  # Closing all open connections
-
         except aioredis.ChannelClosedError:
             # Shutting down...
             logger.info(f"{self.name}: Unsubscribed from {send_channel.name}.")
@@ -81,8 +75,14 @@ class RedisPubSubApp(BaseApp):
         )
 
     async def stop(self, *args, **kwargs):
-        await super().stop(*args, **kwargs)
-
         if self._channel_reader_task is not None:
             self._channel_reader_task.cancel()
             await self._channel_reader_task
+
+        with await self.redis_pool as conn:
+            await conn.unsubscribe(self.SEND_CHANNEL)
+
+        self.redis_pool.close()
+        await self.redis_pool.wait_closed()  # Closing all open connections
+
+        await super().stop(*args, **kwargs)
