@@ -18,12 +18,13 @@
 import asyncio
 import os
 import uuid
-from asyncio import IncompleteReadError, LimitOverrunError
+from asyncio import IncompleteReadError
 from pathlib import Path
 
 from wtfix.apps.base import BaseApp
 from wtfix.conf import settings
 from wtfix.core import utils
+from wtfix.pipeline import BasePipeline
 from wtfix.protocol.contextlib import connection
 
 
@@ -38,7 +39,13 @@ class SessionApp(BaseApp):
     name = "session"
 
     def __init__(
-        self, pipeline, new_session=False, sid_path=None, sender=None, *args, **kwargs
+        self,
+        pipeline: BasePipeline,
+        new_session: bool = False,
+        sid_path: Path = None,
+        sender: str = None,
+        *args,
+        **kwargs,
     ):
         super().__init__(pipeline, *args, **kwargs)
 
@@ -59,7 +66,7 @@ class SessionApp(BaseApp):
         self.writer = None
 
     @property
-    def session_id(self):
+    def session_id(self) -> str:
         return self._session_id
 
     @property
@@ -110,7 +117,13 @@ class ClientSessionApp(SessionApp):
     name = "client_session"
 
     def __init__(
-        self, pipeline, new_session=False, sender=None, target=None, *args, **kwargs
+        self,
+        pipeline: BasePipeline,
+        new_session: bool = False,
+        sender: str = None,
+        target: str = None,
+        *args,
+        **kwargs,
     ):
         super().__init__(
             pipeline, new_session=new_session, sender=sender, *args, **kwargs
@@ -162,13 +175,25 @@ class ClientSessionApp(SessionApp):
         """
         Close the writer.
         """
-        await super().stop(*args, **kwargs)
+        if self.writer is not None:
+            logger.info(
+                f"{self.name}: Initiating disconnect from "
+                f"{self.pipeline.settings.HOST}:{self.pipeline.settings.PORT}..."
+            )
+
+            self.writer.close()
+            logger.info(f"{self.name}: Session closed!")
 
         if self._listener_task is not None:
             logger.info(f"{self.name}: Cancelling listener task...")
 
             self._listener_task.cancel()
-            await self._listener_task
+            try:
+                await self._listener_task
+            except asyncio.exceptions.CancelledError:
+                logger.info(f"{self.name}: {self._listener_task.get_name()} cancelled!")
+
+        await super().stop(*args, **kwargs)
 
     async def listen(self):
         """
@@ -202,8 +227,7 @@ class ClientSessionApp(SessionApp):
                     await self.pipeline.receive(data)
                     data = None
 
-                except IncompleteReadError as e:
-                    # Connection was closed before a complete message could be received.
+                except IncompleteReadError:
                     if (
                         data
                         and utils.encode(
@@ -212,53 +236,36 @@ class ClientSessionApp(SessionApp):
                         + settings.SOH
                         in data
                     ):
+                        # Connection was closed before a complete message could be received.
                         await self.pipeline.receive(
                             data
                         )  # Process logout message in the pipeline as per normal
-
-                        raise e
+                        break
 
                     else:
-                        logger.error(
-                            f"{self.name}: Unexpected EOF waiting for next chunk of partial data "
-                            f"'{utils.decode(e.partial)}' ({e})."
-                        )
-
-                        raise e
-
-                except LimitOverrunError as e:
-                    # Buffer limit reached before a complete message could be read - abort!
-                    logger.error(
-                        f"{self.name}: Stream reader buffer limit exceeded! ({e})."
-                    )
-
-                    raise e
-
-        except asyncio.exceptions.CancelledError:
-            # Cancellation request received - close writer
-            logger.info(f"{self.name}: {asyncio.current_task().get_name()} cancelled!")
-
-            if self.writer is not None:
-                logger.info(
-                    f"{self.name}: Initiating disconnect from "
-                    f"{self.pipeline.settings.HOST}:{self.pipeline.settings.PORT}..."
-                )
-
-                self.writer.close()
-                await self.writer.wait_closed()
-                logger.info(f"{self.name}: Session closed!")
+                        # Something else went wrong, re-raise
+                        raise
 
         except Exception as e:
-            logger.error(f"{self.name}: Unexpected error {e}. Initiating shutdown...")
-            asyncio.create_task(self.pipeline.stop())
+            # Unhandled exception - abort!
+            asyncio.create_task(self.pipeline.stop(e))
 
-    async def on_send(self, message):
+    async def on_send(self, message: bytes):
         """
         Writes an encoded message to the StreamWriter.
 
         :param message: A valid, encoded, FIX message.
         """
-        self.writer.write(message)
-        await self.writer.drain()
+        try:
+            self.writer.write(message)
+            await self.writer.drain()
+        except AttributeError:
+            # Ignore send failures if pipeline is already shutting down.
+            if not self.writer and self.pipeline.stopping_event.is_set():
+                logger.warning(
+                    f"{self.name}: No connection established, cannot send message {message}."
+                )
+            else:
+                raise
 
         del message  # Encourage garbage collection of message once it has been sent
