@@ -1,4 +1,5 @@
 import asyncio
+from collections import OrderedDict
 from unittest.mock import MagicMock
 
 import pytest
@@ -45,6 +46,9 @@ class TestBasePipeline:
                 connection_name=conn.name, installed_apps=three_level_app_chain
             )
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             func, app_chain = pipeline._setup_message_handling(
                 pipeline.INBOUND_PROCESSING
             )
@@ -59,6 +63,9 @@ class TestBasePipeline:
                 connection_name=conn.name, installed_apps=three_level_app_chain
             )
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             func, app_chain = pipeline._setup_message_handling(
                 pipeline.OUTBOUND_PROCESSING
             )
@@ -201,6 +208,9 @@ class TestBasePipeline:
 
                 pipeline._installed_apps[key] = app_mock
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             await pipeline.stop()
 
             for app in pipeline.apps.values():
@@ -213,43 +223,6 @@ class TestBasePipeline:
             ]
             assert call_order == list(pipeline.apps.keys())
 
-    @pytest.mark.asyncio
-    async def test_stop_reports_active_tasks(
-        self, three_level_app_chain, create_mock_coro, caplog
-    ):
-
-        mock_, _ = create_mock_coro(to_patch="wtfix.apps.base.BaseApp.stop")
-
-        with connection_manager() as conn:
-            pipeline = BasePipeline(
-                connection_name=conn.name, installed_apps=three_level_app_chain
-            )
-
-            # Spawn a task that needs to be reported as running in pipeline.stop()
-            running_task = asyncio.create_task(asyncio.sleep(1_000))
-
-            tasks = [
-                task
-                for task in asyncio.all_tasks()
-                if task is not asyncio.current_task()
-            ]
-
-            assert len(tasks) > 0
-
-            await pipeline.stop()
-
-            tasks = [
-                task
-                for task in asyncio.all_tasks()
-                if task is not asyncio.current_task()
-            ]
-
-            assert len(tasks) == 1
-            assert mock_.call_count == len(pipeline._installed_apps)
-            assert f"There are still {len(tasks)} tasks" in caplog.text
-
-            running_task.cancel()
-
     @pytest.mark.asyncio
     async def test_stop_allows_only_one_stop_process_to_run_concurrently(
         self, three_level_app_chain
@@ -265,6 +238,9 @@ class TestBasePipeline:
 
                 pipeline._installed_apps[key] = app_mock
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             asyncio.create_task(pipeline.stop())
             asyncio.create_task(pipeline.stop())
             asyncio.create_task(pipeline.stop())
@@ -290,6 +266,9 @@ class TestBasePipeline:
 
                 pipeline._installed_apps[key] = app_mock
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             await pipeline.stop()
             await pipeline.stop()
 
@@ -304,6 +283,9 @@ class TestBasePipeline:
                 connection_name=conn.name, installed_apps=three_level_app_chain
             )
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             message = await pipeline.receive(admin.TestRequestMessage("Test"))
             assert message.TestReqID == "Test r1 r2 r3"
 
@@ -314,6 +296,9 @@ class TestBasePipeline:
                 connection_name=conn.name, installed_apps=three_level_stop_app_chain
             )
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             message = await pipeline.receive(admin.TestRequestMessage("Test"))
             assert message.TestReqID == "Test r1"
 
@@ -324,6 +309,9 @@ class TestBasePipeline:
                 connection_name=conn.name, installed_apps=three_level_app_chain
             )
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             message = await pipeline.send(admin.TestRequestMessage("Test"))
             assert message.TestReqID == "Test s3 s2 s1"
 
@@ -334,5 +322,8 @@ class TestBasePipeline:
                 connection_name=conn.name, installed_apps=three_level_stop_app_chain
             )
 
+            # Simulate all apps active
+            pipeline._active_apps = OrderedDict(pipeline.apps.items())
+
             message = await pipeline.send(admin.TestRequestMessage("Test"))
             assert message.TestReqID == "Test s3"
